# `royalnet` 6

The repository for the development of `royalnet` version `6.0.0` and later.

The documentation is [hosted on Read The Docs](https://royalnet-6.readthedocs.io/en/latest/).

## See also

### PDA implementations

- [royalnet-discordpy](https://github.com/Steffo99/royalnet-discordpy) (based on a Discord Bot)
- [royalnet-console](https://github.com/Steffo99/royalnet-console) (based on a terminal session)

### Old Royalnet versions

- [Royalnet 5](https://github.com/Steffo99/royalnet-5)
- [Royalnet 4](https://github.com/Steffo99/royalnet-5/tree/four)
- [Royalbot 3](https://github.com/Steffo99/royalbot-3)
- [Royalbot 2](https://github.com/Steffo99/royalbot-2)
- [Royalbot 1](https://github.com/Steffo99/royalbot-1)
